/*
 * This file is part of QMAFW
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies). All rights
 * reserved.
 *
 * Contact: Visa Smolander <visa.smolander@nokia.com>
 *
 * This software, including documentation, is protected by copyright controlled
 * by Nokia Corporation. All rights are reserved. Copying, including
 * reproducing, storing, adapting or translating, any or all of this material
 * requires the prior written consent of Nokia Corporation. This material also
 * contains confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 *
 */

#ifndef MAFWPLAYLISTBASE_H_
#define MAFWPLAYLISTBASE_H_

#include <QObject>

#include "MafwPlaylist.h"

class MafwPlaylistBasePrivate;
class QAbstractItemoModel;

/**
 * @brief The class providing implementation base for playlists in MAFW.
 */
class MafwPlaylistBase : public MafwPlaylist
{
    Q_OBJECT

    friend class MafwPlaylistBasePrivate;

protected:
    MafwPlaylistBase(const QString& id, const QString& name);

public:

    /**
     * The destructor
     */
    virtual ~MafwPlaylistBase();

    /**
      * Set model to be used as playlist. Concrete implementation classes
      * that inherit this base class may have certain restrictions for the model.
      *
      * The default implementation does not take ownership of the model.
      */
    void setUnderlyingModel(QAbstractItemModel* model);

    /**
     * Returns the underlying model represented by this playlist.
     * This is not the same as MafwPlaylist::getModel(), which may have
     * proxy layers to handle sorting etc.
     *
     * The underlying model is not owned by the playlist, so ownership is
     * not transferred using this function.
     *
     * @return The actual underlying model represented by this playlist.
     */
    QAbstractItemModel* underlyingModel();

//From MafwPlaylist
    /**
     * Returns a proxy playlist object representing the
     * actual underlying model.
     *
     * @see underlyingModel()
     * @return a model of the contents of this playlist.
     */
    QAbstractItemModel& model();
    void sort( int column, MafwSortOrder sortOrder = AscendingOrder );
    void sort( QString columnName, MafwSortOrder sortOrder = AscendingOrder );
    QStringList getColumnNames();
    void shuffle();
    void unShuffle();
    bool removeItem( int index );
    bool removeItems(int firstIndex, int lastIndex );

    /**
      * Move is not supported.
      */
    bool moveItem( int from, int to );
    void clear();
    MafwContent* getItem( int index );
    int size();
    int getCurrentIndex();
    int getNext( int index );
    int getPrevious( int index );
    void setRepeat( MafwPlaylist::MafwRepeatMode mode );
    MafwRepeatMode repeatMode();
    MafwSortOrder getSortOrder();
    bool isShuffled();
    bool import( QFile& file );

private:
    MafwPlaylistBasePrivate* d;
};

#endif /*MAFWPLAYLISTBASE_H_*/
