/*
 * This file is part of QMAFW
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies). All rights
 * reserved.
 *
 * Contact: Visa Smolander <visa.smolander@nokia.com>
 *
 * This software, including documentation, is protected by copyright controlled
 * by Nokia Corporation. All rights are reserved. Copying, including
 * reproducing, storing, adapting or translating, any or all of this material
 * requires the prior written consent of Nokia Corporation. This material also
 * contains confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 *
 */

#ifndef MAFW_RENDERER_POLICY_PLUGIN_H
#define MAFW_RENDERER_POLICY_PLUGIN_H

#include <QtPlugin>

#include <MafwRendererPolicy.h>

/**
 * This class provides possibility to implement a renderer policy as a loadable
 * plugin.
 */
class MafwRendererPolicyPlugin
{

public:

    /**
     * Helper that loads given renderer policy plugin and gets and returns the
     * actual policy object.
     * @param name The name of the policy plugin
     * @return Pointer to uninitialized policy plugin, non-zero if it could be loaded
     */
    static MafwRendererPolicy* loadPolicy(const QString& name);

public:

    /**
     * Implement this to instantiate the actual policy object.
     * @return Pointer to an uninitialized MafwRendererPolicy object.
     */
    virtual MafwRendererPolicy* getPolicy() = 0;

};

Q_DECLARE_INTERFACE(MafwRendererPolicyPlugin, "com.nokia.mafw.MafwRendererPolicyPlugin")

#endif
